@@ -31,12 +31,12 @@ class ArchiveManager(Policy):
         self.default = default
         self.default_archive_manager = default_archive_manager
         self.default_config_elements = [
-            glasswall.content_management.config_elements.archiveConfig,
-            glasswall.content_management.config_elements.pdfConfig,
-            glasswall.content_management.config_elements.pptConfig,
-            glasswall.content_management.config_elements.tiffConfig,
-            glasswall.content_management.config_elements.wordConfig,
-            glasswall.content_management.config_elements.xlsConfig,
+            glasswall.content_management.config_elements.archiveConfig(default=default_archive_manager),
+            glasswall.content_management.config_elements.pdfConfig(default=default),
+            glasswall.content_management.config_elements.pptConfig(default=default),
+            glasswall.content_management.config_elements.tiffConfig(default=default),
+            glasswall.content_management.config_elements.wordConfig(default=default),
+            glasswall.content_management.config_elements.xlsConfig(default=default),
         ]
         self.config = config or {}
 
